Geospatial Disasters API Service
================================
Query broadcasted news related to natural disasters and visualize them using spatial aggregations.

This modern Python module represents an idiomatic client accessing the `Geodisasters location services <https://geospatial-ai.de/?rara-portfolio=geospatial-disasters-api-service>`__ being hosted on `Rapid API Hub <https://v2.rapidapi.com/gisfromscratch/api/geodisasters>`__.

Next steps
----------
Please, check out the `RapidAPI Account Creation and Management Guide <https://docs.rapidapi.com/docs/account-creation-and-settings>`__.

Start with the :doc:`usage` section for further information, including
how to :ref:`installation` the Python module.

.. note::

   This project is under active development.

Contents
--------

.. toctree::

   usage
   api
